OC.L10N.register(
    "firstrunwizard",
    {
    "A safe home for all your data" : "Bezpieczne miejsce dla wszystkich Twoich informacji",
    "Get the apps to sync your files" : "Pobierz aplikacje aby zsynchronizować swoje pliki",
    "Desktop client" : "Klient na komputer",
    "Android app" : "Aplikacja Android",
    "iOS app" : "Aplikacja iOS",
    "Connect your desktop apps to %s" : "Podłącz swoje aplikacje na komputerze do %s",
    "Connect your Calendar" : "Podłącz swój kalendarz",
    "Connect your Contacts" : "Podłącz swoje Kontakty",
    "Documentation" : "Dokumentacja",
    "Access files via WebDAV" : "Uzyskaj dostęp do plików poprzez WebDAV",
    "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"http://owncloud.org\">website</a>." : "Więcej informacji znajduje się w <a target=\"_blank\" href=\"%s\">dokumentacji</a> i na naszej <a target=\"_blank\" href=\"http://owncloud.org\">stronie</a>."
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>=14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
